#
# spec file for package python-openTSNE
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-openTSNE
Version:        1.0.0
Release:        1.1
Summary:        Extensible, parallel implementations of t-SNE
License:        BSD-3-Clause
URL:            https://github.com/pavlin-policar/openTSNE
# tests are not packaged in the PyPI sdist, use GitHub instead
Source:         %{url}/archive/v%{version}.tar.gz#/openTSNE-%{version}-gh.tar.gz
Patch0:         python-openTSNE-disable-CPU-autodetection.patch
# PATCH-FIX-UPSTREAM https://github.com/pavlin-policar/openTSNE/commit/07d8ad1f89356dc77a503071a16516873f4d4e30 Fix #248: get_numpy_include class error in new pip
Patch1:         get-numpy-include.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module numpy-devel >= 1.16.6}
BuildRequires:  %{python_module scikit-learn >= 0.20}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
Requires:       python-numpy >= 1.16.6
Requires:       python-scikit-learn >= 0.20
Requires:       python-scipy
Suggests:       python-hnswlib
Suggests:       python-pynndescent
Provides:       python-fastTSNE = %{version}
Obsoletes:      python-fastTSNE < %{version}
%python_subpackages

%description
Extensible, parallel implementations of t-SNE

%prep
%autosetup -p1 -n openTSNE-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%ifarch %ix86 %arm32
# precision errors on 32bit
%define donttest -k "not TestTSNECorrectnessUsingPrecomputedDistanceMatrix"
%endif
%pytest_arch --import-mode append %{?donttest}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/openTSNE
%{python_sitearch}/openTSNE-%{version}*-info

%changelog
* Thu Sep 14 2023 Markéta Machová <mmachova@suse.com>
- Update to 1.0.0
  * Given the longtime stability of openTSNE, it is only fitting
    that we release a v1.0.0.
  * Various documentation fixes
  * Include Python 3.11 in the test and build matrix
  * Uniform affinity kernel now supports mean and max mode
- add get-numpy-include.patch
* Sun Mar 20 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.6.2
  * By default, we now use the MultiscaleMixture affinity model,
    enabling us to pass in a list of perplexities instead of a
    single perplexity value. This is fully backwards compatible.
  * Previously, perplexity values would be changed according to the
    dataset. E.g. we pass in perplexity=100 with N=150. Then
    TSNE.perplexity would be equal to 50. Instead, keep this value
    as is and add an effective_perplexity_ attribute (following the
    convention from scikit-learn, which puts in the corrected
    perplexity values.
  * Fix bug where interpolation grid was being prepared even when
    using BH optimization during transform.
  * Enable calling .transform with precomputed distances. In this
    case, the data matrix will be assumed to be a distance matrix.
  * Fix potential problem with clang-13, which actually does
    optimization with infinities using the -ffast-math flag
- Enable python310 build
- Skip a test in 32bit failing due to rounding errors
* Fri Feb  4 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.6.1
  * Remove affinites from TSNE construction, allow custom
    affinities and initialization in .fit method. This improves the
    API when dealing with non-tabular data. This is not backwards
    compatible.
  * Add metric="precomputed". This includes the addition of
    openTSNE.nearest_neighbors.PrecomputedDistanceMatrix and
    openTSNE.nearest_neighbors.PrecomputedNeighbors.
  * Add knn_index parameter to openTSNE.affinity classes.
  * Add (less-than-ideal) workaround for pickling Annoy objects.
  * Extend the range of recommended FFTW boxes up to 1000.
  * Remove deprecated openTSNE.nearest_neighbors.BallTree.
  * Remove deprecated openTSNE.callbacks.ErrorLogger.
  * Remove deprecated TSNE.neighbors_method property.
  * Add and set as default negative_gradient_method="auto".
- Skip building on python310: gh#pavlin-policar/openTSNE#205
* Thu Apr  1 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Add python-openTSNE-disable-CPU-autodetection.patch (boo#1100677)
* Fri Jan 29 2021 Ben Greiner <code@bnavigator.de>
- initial specfile for version 0.5.1
- replaces python-fastTSNE
- The pytest_arch macro needs the "Cepl-Strangelove-Parameter"
  (= specify --import-mode)
